@@ -3,6 +3,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
 
+
 CLASS_NAMES = getattr(settings, "CMS_STYLE_NAMES", (
         ('info', _("info")),
         ('new', _("new")),
@@ -10,6 +11,7 @@ CLASS_NAMES = getattr(settings, "CMS_STYLE_NAMES", (
     )
 )
 
+
 class Style(CMSPlugin):
     """
     A CSS Style Plugin
@@ -19,16 +21,17 @@ class Style(CMSPlugin):
     ARTICLE_TAG = 'article'
     SECTION_TAG = 'section'
 
-    HTML_TAG_TYPES = (
-        (DIV_TAG, _('div')),
-        (ARTICLE_TAG, _('article')),
-        (SECTION_TAG, _('section')),
+    HTML_TAG_TYPES = getattr(settings, "CMS_STYLE_TAG_TYPES", (
+            (DIV_TAG, _('div')),
+            (ARTICLE_TAG, _('article')),
+            (SECTION_TAG, _('section')),
+        )
     )
 
     cmsplugin_ptr = models.OneToOneField(CMSPlugin, related_name='+', parent_link=True)
     class_name = models.CharField(_("class name"), choices=CLASS_NAMES, default=CLASS_NAMES[0][0], max_length=50, blank=True, null=True)
 
-    tag_type = models.CharField(verbose_name=_('tag Type'), max_length=50, choices=HTML_TAG_TYPES, default=DIV_TAG)
+    tag_type = models.CharField(verbose_name=_('tag Type'), max_length=50, choices=HTML_TAG_TYPES, default=HTML_TAG_TYPES[0][0])
 
     padding_left = models.SmallIntegerField(_("padding left"), blank=True, null=True)
     padding_right = models.SmallIntegerField(_("padding right"), blank=True, null=True)
